#!/bin/sh
#
# $FreeBSD: ports/net-mgmt/nagios/files/nagios.sh.in,v 1.2 2006/01/17 10:39:58 tdb Exp $
#

#
# Add the following lines to /etc/rc.conf to enable nagios:
# nagios_enable (bool):    Set to "NO" by default.
#                          Set it to "YES" to enable nagios.
# nagios_flags (str):      Set to "" by default.
# nagios_configfile (str): Set to "/usr/local/etc/nagios/nagios.cfg" by default.
#

. /etc/rc.subr

name="nagios"
rcvar=`set_rcvar`

command="/usr/local/bin/nagios"
command_args="-d"
extra_commands="reload"
pidfile="/var/spool/nagios/nagios.lock"
nagios_user="nagios"

start_precmd="start_precmd"
stop_postcmd="stop_postcmd"
restart_precmd="nagios_checkconfig"
sig_reload=HUP

[ -z "${nagios_enable}" ]       && nagios_enable="NO"
[ -z "${nagios_flags}" ]        && nagios_flags=""
[ -z "${nagios_configfile}" ]   && nagios_configfile="/usr/local/etc/nagios/nagios.cfg"

load_rc_config "${name}"

required_files="${nagios_configfile}"
command_args="${command_args} ${nagios_configfile}"

nagios_checkconfig() {
  echo -n "Performing sanity check of nagios configuration: "
  ${command} -v ${nagios_configfile} 2>&1 >/dev/null
  if [ $? != 0 ]; then
    echo "FAILED"
    ${command} -v ${nagios_configfile}
    return 1
  else
    echo "OK"
  fi
}

start_precmd() {
  if ! nagios_checkconfig; then
    return 1
  fi

  su -m "${nagios_user}" -c "touch \"/var/spool/nagios/nagios.log\" \"/var/spool/nagios/status.sav\""
  rm -f "/var/spool/nagios/rw/nagios.cmd"
}

stop_postcmd() {
  rm -f "/var/spool/nagios/nagios.tmp" "/var/spool/nagios/rw/nagios.cmd"
}

run_rc_command "$1"
